Documentation
¶
Index ¶
Constants ¶
const ( SDL = iota WEB )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DrawSpec ¶
type DrawSpec struct {
E entity.Entity
Loc locationmanager.Combination
}
DrawSpec is a combination of entity and location to send to anyone who might want to output it.
type Manager ¶
type Manager interface {
// Shutdown turns of all IO.
Shutdown()
// Add registers an output channel with the Manager.
Add(t IoType, out chan []DrawSpec)
// Distribute sends the given entities out down all the output channels.
Distribute(data []entity.Entity)
// Handle is called by any input monitors to let the Manager deal with events.
Handle(e events.Event)
}
Manager is capable of handling multiple input/output paths at once. It abstracts this away from the main thread.
Click to show internal directories.
Click to hide internal directories.